@@ -1,19 +1,19 @@
 #!/usr/bin/env python
 
-'''
+"""
 Receives up to date data from the DTrace consumer.
 
 Created on Mar 31, 2012
 
 @author: tmetsch
-'''
-
+"""
+from __future__ import print_function
 import ast
 import pika
 
 # Connection to the broker.
 connection = pika.BlockingConnection(pika.ConnectionParameters(
-                                     host='localhost'))
+    host='localhost'))
 channel = connection.channel()
 channel.queue_declare(queue='dtrace')
 
@@ -21,10 +21,10 @@ channel.queue_declare(queue='dtrace')
 data = {}
 
 
-def callback(ch, method, properties, body):
-    '''
+def callback(_ch, _method, _properties, body):
+    """
     Callback which picks up the DTrace messages.
-    '''
+    """
     tmp = ast.literal_eval(body)
     key = tmp.keys()[0]
     val = tmp.values()[0]
@@ -34,12 +34,13 @@ def callback(ch, method, properties, body):
         data[key] = val
     # Print instead of doing print you could life update a chart...msg will
     # come as DTrace fires them
-    print 'Received: ', key, val
+    print('Received: ', key, val)
+
 
 if __name__ == '__main__':
-    channel.basic_consume(callback,
+    channel.basic_consume(on_message_callback=callback,
                           queue='dtrace',
-                          no_ack=True)
+                          auto_ack=False)
 
     try:
         channel.start_consuming()
