@@ -9,26 +9,28 @@ Created on Mar 31, 2012
 @author: tmetsch
 """
 
-import dtrace
-import pika
 import time
 
+import pika
+
+import dtrace
+
 # pretty num D script counting syscalls...
 SCRIPT = 'syscall:::entry { @num[execname] = count(); }'
 
 # Connection to the broker
 connection = pika.BlockingConnection(pika.ConnectionParameters(
-                                     host='localhost'))
+    host='localhost'))
 channel = connection.channel()
 channel.queue_declare(queue='dtrace')
 
 
-def walk(iden, key, value):
+def walk(_iden, key, value):
     """
     Walker which sends on the data to RabbitMQ as the DTrace probes fire.
     """
     channel.basic_publish(exchange='', routing_key='dtrace',
-                          body=str({key[0]: value}))
+                          body=bytes({key[0]: value}))
 
 
 def run_dtrace():
@@ -45,6 +47,7 @@ def run_dtrace():
     thr.stop()
     thr.join()
 
+
 if __name__ == '__main__':
     run_dtrace()
     connection.close()
