@@ -1,31 +1,33 @@
 #!/usr/bin/env python
 
-'''
+"""
 Use the Python DTrace consumer and count syscalls by zone.
 
 Created on Oct 10, 2011
 
 @author: tmetsch
-'''
+"""
+from __future__ import print_function
 
-from dtrace import DTraceConsumerThread
 import time
 
+import dtrace
+
 SCRIPT = 'syscall:::entry { @num[zonename] = count(); }'
 
 
-def my_walk(action, identifier, key, value):
-    '''
+def my_walk(_action, _identifier, key, value):
+    """
     A simple aggregate walker.
-    '''
-    print 'Zone "{0:s}" made {1:d} syscalls.'.format(key[0], value)
+    """
+    print('Zone "{0:s}" made {1:d} syscalls.'.format(key[0].decode(), value))
 
 
 def main():
-    '''
+    """
     Run DTrace...
-    '''
-    thr = DTraceConsumerThread(SCRIPT, walk_func=my_walk, sleep=1)
+    """
+    thr = dtrace.DTraceConsumerThread(SCRIPT, walk_func=my_walk, sleep=1)
     thr.start()
 
     # we will stop the thread after some time...
@@ -35,5 +37,6 @@ def main():
     thr.stop()
     thr.join()
 
+
 if __name__ == '__main__':
     main()
